Package: DSOpal
Type: Package
Title: 'DataSHIELD' Implementation for 'Opal'
Version: 1.5.0
Authors@R: 
    c(person(given = "Yannick",
             family = "Marcon",
             role = c("aut", "cre"),
             email = "yannick.marcon@obiba.org",
             comment = c(ORCID = "0000-0003-0138-2023")),
      person(given = "Becca",
             family = "Wilson",
             role = "ctb",
             comment = c(ORCID = "0000-0003-2294-593X")),
      person("OBiBa group",
             role="cph",
             email="info@obiba.org"))
Depends: R (>= 3.5), opalr (>= 3.5), DSI (>= 1.8), methods, utils
Description: 'DataSHIELD' is an infrastructure and series of R packages that 
    enables the remote and 'non-disclosive' analysis of sensitive research data.
    This package is the 'DataSHIELD' interface implementation for 'Opal', which is
    the data integration application for biobanks by 'OBiBa'. Participant data, once
    collected from any data source, must be integrated and stored in a central
    data repository under a uniform model. 'Opal' is such a central repository.
    It can import, process, validate, query, analyze, report, and export data.
    'Opal' is the reference implementation of the 'DataSHIELD' infrastructure.
License: LGPL (>= 2.1)
URL: https://github.com/datashield/DSOpal/,
        https://datashield.github.io/DSOpal/, https://www.obiba.org,
        https://www.obiba.org/pages/products/opal/,
        https://datashield.org/,
        https://academic.oup.com/ije/article/43/6/1929/707730,
        https://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1008880
BugReports: https://github.com/datashield/DSOpal/issues/
RoxygenNote: 7.3.3
Encoding: UTF-8
Collate: 'DSOpal-package.R' 'OpalDriver.R' 'OpalConnection.R'
        'OpalResult.R' 'OpalSession.R' 'datashield.aggregate.r'
        'datashield.assign.r' 'datashield.command.r'
        'datashield.method.r' 'datashield.symbol.r'
        'datashield.workspace.r' 'logindata.R' 'utils.R'
NeedsCompilation: no
Packaged: 2025-11-05 17:33:15 UTC; ymarcon
Author: Yannick Marcon [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0138-2023>),
  Becca Wilson [ctb] (ORCID: <https://orcid.org/0000-0003-2294-593X>),
  OBiBa group [cph]
Maintainer: Yannick Marcon <yannick.marcon@obiba.org>
Repository: CRAN
Date/Publication: 2025-11-05 19:30:10 UTC
Built: R 4.6.0; ; 2026-04-30 22:36:10 UTC; unix
