# Generated by roxygen2: do not edit by hand

export(Opal)
exportClasses(OpalConnection)
exportClasses(OpalDriver)
exportClasses(OpalResult)
exportClasses(OpalSession)
exportMethods(dsAggregate)
exportMethods(dsAssignExpr)
exportMethods(dsAssignResource)
exportMethods(dsAssignTable)
exportMethods(dsConnect)
exportMethods(dsDisconnect)
exportMethods(dsFetch)
exportMethods(dsGetInfo)
exportMethods(dsHasResource)
exportMethods(dsHasSession)
exportMethods(dsHasTable)
exportMethods(dsIsAsync)
exportMethods(dsIsCompleted)
exportMethods(dsIsReady)
exportMethods(dsKeepAlive)
exportMethods(dsListMethods)
exportMethods(dsListPackages)
exportMethods(dsListProfiles)
exportMethods(dsListResources)
exportMethods(dsListSymbols)
exportMethods(dsListTables)
exportMethods(dsListWorkspaces)
exportMethods(dsRestoreWorkspace)
exportMethods(dsRmSymbol)
exportMethods(dsRmWorkspace)
exportMethods(dsSaveWorkspace)
exportMethods(dsSession)
exportMethods(dsStateMessage)
import(DSI)
import(methods)
import(opalr)
import(utils)
