# DataSHIELD Opal

[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/DSOpal)](https://cran.r-project.org/package=DSOpal)
[![R-CMD-check](https://github.com/datashield/DSOpal/actions/workflows/ci.yml/badge.svg)](https://github.com/datashield/DSOpal/actions/workflows/ci.yml)

[DataSHIELD Interface (DSI)](https://datashield.github.io/DSI/) implementation for 
[Opal](https://www.obiba.org/pages/products/opal/) data warehouse, based on 
[Opal R Client (opalr)](https://www.obiba.org/opalr/) package.

This is the reference implementation of the DataSHIELD Interface that can be used for implementing other data 
repository clients supporting DataSHIELD infrastructure.

See usage [examples](https://github.com/datashield/DSOpal/tree/master/inst/examples).

Articles about Opal and DataSHIELD:
* [DataSHIELD – New Directions and Dimensions](https://doi.org/10.5334/dsj-2017-021)
* [DataSHIELD: taking the analysis to the data, not the data to the analysis](https://doi.org/10.1093/ije/dyu188)
* [Software Application Profile: Opal and Mica: open-source software solutions for epidemiological data management, harmonization and dissemination](https://doi.org/10.1093/ije/dyx180)
